@@ -6,9 +6,9 @@ Type annotations for databrew service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_databrew.type_defs import BatchDeleteRecipeVersionResponseTypeDef
+    from mypy_boto3_databrew.type_defs import BatchDeleteRecipeVersionRequestTypeDef
 
-    data: BatchDeleteRecipeVersionResponseTypeDef = {...}
+    data: BatchDeleteRecipeVersionRequestTypeDef = {...}
     ```
 """
 import sys
@@ -42,14 +42,21 @@ else:
 
 
 __all__ = (
-    "BatchDeleteRecipeVersionResponseTypeDef",
+    "BatchDeleteRecipeVersionRequestTypeDef",
+    "BatchDeleteRecipeVersionResponseResponseTypeDef",
     "ConditionExpressionTypeDef",
-    "CreateDatasetResponseTypeDef",
-    "CreateProfileJobResponseTypeDef",
-    "CreateProjectResponseTypeDef",
-    "CreateRecipeJobResponseTypeDef",
-    "CreateRecipeResponseTypeDef",
-    "CreateScheduleResponseTypeDef",
+    "CreateDatasetRequestTypeDef",
+    "CreateDatasetResponseResponseTypeDef",
+    "CreateProfileJobRequestTypeDef",
+    "CreateProfileJobResponseResponseTypeDef",
+    "CreateProjectRequestTypeDef",
+    "CreateProjectResponseResponseTypeDef",
+    "CreateRecipeJobRequestTypeDef",
+    "CreateRecipeJobResponseResponseTypeDef",
+    "CreateRecipeRequestTypeDef",
+    "CreateRecipeResponseResponseTypeDef",
+    "CreateScheduleRequestTypeDef",
+    "CreateScheduleResponseResponseTypeDef",
     "CsvOptionsTypeDef",
     "CsvOutputOptionsTypeDef",
     "DataCatalogInputDefinitionTypeDef",
@@ -57,17 +64,28 @@ __all__ = (
     "DatasetParameterTypeDef",
     "DatasetTypeDef",
     "DatetimeOptionsTypeDef",
-    "DeleteDatasetResponseTypeDef",
-    "DeleteJobResponseTypeDef",
-    "DeleteProjectResponseTypeDef",
-    "DeleteRecipeVersionResponseTypeDef",
-    "DeleteScheduleResponseTypeDef",
-    "DescribeDatasetResponseTypeDef",
-    "DescribeJobResponseTypeDef",
-    "DescribeJobRunResponseTypeDef",
-    "DescribeProjectResponseTypeDef",
-    "DescribeRecipeResponseTypeDef",
-    "DescribeScheduleResponseTypeDef",
+    "DeleteDatasetRequestTypeDef",
+    "DeleteDatasetResponseResponseTypeDef",
+    "DeleteJobRequestTypeDef",
+    "DeleteJobResponseResponseTypeDef",
+    "DeleteProjectRequestTypeDef",
+    "DeleteProjectResponseResponseTypeDef",
+    "DeleteRecipeVersionRequestTypeDef",
+    "DeleteRecipeVersionResponseResponseTypeDef",
+    "DeleteScheduleRequestTypeDef",
+    "DeleteScheduleResponseResponseTypeDef",
+    "DescribeDatasetRequestTypeDef",
+    "DescribeDatasetResponseResponseTypeDef",
+    "DescribeJobRequestTypeDef",
+    "DescribeJobResponseResponseTypeDef",
+    "DescribeJobRunRequestTypeDef",
+    "DescribeJobRunResponseResponseTypeDef",
+    "DescribeProjectRequestTypeDef",
+    "DescribeProjectResponseResponseTypeDef",
+    "DescribeRecipeRequestTypeDef",
+    "DescribeRecipeResponseResponseTypeDef",
+    "DescribeScheduleRequestTypeDef",
+    "DescribeScheduleResponseResponseTypeDef",
     "ExcelOptionsTypeDef",
     "FilesLimitTypeDef",
     "FilterExpressionTypeDef",
@@ -77,20 +95,29 @@ __all__ = (
     "JobSampleTypeDef",
     "JobTypeDef",
     "JsonOptionsTypeDef",
-    "ListDatasetsResponseTypeDef",
-    "ListJobRunsResponseTypeDef",
-    "ListJobsResponseTypeDef",
-    "ListProjectsResponseTypeDef",
-    "ListRecipeVersionsResponseTypeDef",
-    "ListRecipesResponseTypeDef",
-    "ListSchedulesResponseTypeDef",
-    "ListTagsForResourceResponseTypeDef",
+    "ListDatasetsRequestTypeDef",
+    "ListDatasetsResponseResponseTypeDef",
+    "ListJobRunsRequestTypeDef",
+    "ListJobRunsResponseResponseTypeDef",
+    "ListJobsRequestTypeDef",
+    "ListJobsResponseResponseTypeDef",
+    "ListProjectsRequestTypeDef",
+    "ListProjectsResponseResponseTypeDef",
+    "ListRecipeVersionsRequestTypeDef",
+    "ListRecipeVersionsResponseResponseTypeDef",
+    "ListRecipesRequestTypeDef",
+    "ListRecipesResponseResponseTypeDef",
+    "ListSchedulesRequestTypeDef",
+    "ListSchedulesResponseResponseTypeDef",
+    "ListTagsForResourceRequestTypeDef",
+    "ListTagsForResourceResponseResponseTypeDef",
     "OutputFormatOptionsTypeDef",
     "OutputTypeDef",
     "PaginatorConfigTypeDef",
     "PathOptionsTypeDef",
     "ProjectTypeDef",
-    "PublishRecipeResponseTypeDef",
+    "PublishRecipeRequestTypeDef",
+    "PublishRecipeResponseResponseTypeDef",
     "RecipeActionTypeDef",
     "RecipeReferenceTypeDef",
     "RecipeStepTypeDef",
@@ -100,41 +127,48 @@ __all__ = (
     "S3LocationTypeDef",
     "SampleTypeDef",
     "ScheduleTypeDef",
-    "SendProjectSessionActionResponseTypeDef",
-    "StartJobRunResponseTypeDef",
-    "StartProjectSessionResponseTypeDef",
-    "StopJobRunResponseTypeDef",
-    "UpdateDatasetResponseTypeDef",
-    "UpdateProfileJobResponseTypeDef",
-    "UpdateProjectResponseTypeDef",
-    "UpdateRecipeJobResponseTypeDef",
-    "UpdateRecipeResponseTypeDef",
-    "UpdateScheduleResponseTypeDef",
+    "SendProjectSessionActionRequestTypeDef",
+    "SendProjectSessionActionResponseResponseTypeDef",
+    "StartJobRunRequestTypeDef",
+    "StartJobRunResponseResponseTypeDef",
+    "StartProjectSessionRequestTypeDef",
+    "StartProjectSessionResponseResponseTypeDef",
+    "StopJobRunRequestTypeDef",
+    "StopJobRunResponseResponseTypeDef",
+    "TagResourceRequestTypeDef",
+    "UntagResourceRequestTypeDef",
+    "UpdateDatasetRequestTypeDef",
+    "UpdateDatasetResponseResponseTypeDef",
+    "UpdateProfileJobRequestTypeDef",
+    "UpdateProfileJobResponseResponseTypeDef",
+    "UpdateProjectRequestTypeDef",
+    "UpdateProjectResponseResponseTypeDef",
+    "UpdateRecipeJobRequestTypeDef",
+    "UpdateRecipeJobResponseResponseTypeDef",
+    "UpdateRecipeRequestTypeDef",
+    "UpdateRecipeResponseResponseTypeDef",
+    "UpdateScheduleRequestTypeDef",
+    "UpdateScheduleResponseResponseTypeDef",
     "ViewFrameTypeDef",
 )
 
-_RequiredBatchDeleteRecipeVersionResponseTypeDef = TypedDict(
-    "_RequiredBatchDeleteRecipeVersionResponseTypeDef",
+BatchDeleteRecipeVersionRequestTypeDef = TypedDict(
+    "BatchDeleteRecipeVersionRequestTypeDef",
     {
         "Name": str,
+        "RecipeVersions": List[str],
     },
 )
-_OptionalBatchDeleteRecipeVersionResponseTypeDef = TypedDict(
-    "_OptionalBatchDeleteRecipeVersionResponseTypeDef",
+
+BatchDeleteRecipeVersionResponseResponseTypeDef = TypedDict(
+    "BatchDeleteRecipeVersionResponseResponseTypeDef",
     {
+        "Name": str,
         "Errors": List["RecipeVersionErrorDetailTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-
-class BatchDeleteRecipeVersionResponseTypeDef(
-    _RequiredBatchDeleteRecipeVersionResponseTypeDef,
-    _OptionalBatchDeleteRecipeVersionResponseTypeDef,
-):
-    pass
-
-
 _RequiredConditionExpressionTypeDef = TypedDict(
     "_RequiredConditionExpressionTypeDef",
     {
@@ -157,45 +191,210 @@ class ConditionExpressionTypeDef(
     pass
 
 
-CreateDatasetResponseTypeDef = TypedDict(
-    "CreateDatasetResponseTypeDef",
+_RequiredCreateDatasetRequestTypeDef = TypedDict(
+    "_RequiredCreateDatasetRequestTypeDef",
     {
         "Name": str,
+        "Input": "InputTypeDef",
+    },
+)
+_OptionalCreateDatasetRequestTypeDef = TypedDict(
+    "_OptionalCreateDatasetRequestTypeDef",
+    {
+        "Format": InputFormatType,
+        "FormatOptions": "FormatOptionsTypeDef",
+        "PathOptions": "PathOptionsTypeDef",
+        "Tags": Dict[str, str],
+    },
+    total=False,
+)
+
+
+class CreateDatasetRequestTypeDef(
+    _RequiredCreateDatasetRequestTypeDef, _OptionalCreateDatasetRequestTypeDef
+):
+    pass
+
+
+CreateDatasetResponseResponseTypeDef = TypedDict(
+    "CreateDatasetResponseResponseTypeDef",
+    {
+        "Name": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-CreateProfileJobResponseTypeDef = TypedDict(
-    "CreateProfileJobResponseTypeDef",
+_RequiredCreateProfileJobRequestTypeDef = TypedDict(
+    "_RequiredCreateProfileJobRequestTypeDef",
+    {
+        "DatasetName": str,
+        "Name": str,
+        "OutputLocation": "S3LocationTypeDef",
+        "RoleArn": str,
+    },
+)
+_OptionalCreateProfileJobRequestTypeDef = TypedDict(
+    "_OptionalCreateProfileJobRequestTypeDef",
+    {
+        "EncryptionKeyArn": str,
+        "EncryptionMode": EncryptionModeType,
+        "LogSubscription": LogSubscriptionType,
+        "MaxCapacity": int,
+        "MaxRetries": int,
+        "Tags": Dict[str, str],
+        "Timeout": int,
+        "JobSample": "JobSampleTypeDef",
+    },
+    total=False,
+)
+
+
+class CreateProfileJobRequestTypeDef(
+    _RequiredCreateProfileJobRequestTypeDef, _OptionalCreateProfileJobRequestTypeDef
+):
+    pass
+
+
+CreateProfileJobResponseResponseTypeDef = TypedDict(
+    "CreateProfileJobResponseResponseTypeDef",
     {
         "Name": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-CreateProjectResponseTypeDef = TypedDict(
-    "CreateProjectResponseTypeDef",
+_RequiredCreateProjectRequestTypeDef = TypedDict(
+    "_RequiredCreateProjectRequestTypeDef",
+    {
+        "DatasetName": str,
+        "Name": str,
+        "RecipeName": str,
+        "RoleArn": str,
+    },
+)
+_OptionalCreateProjectRequestTypeDef = TypedDict(
+    "_OptionalCreateProjectRequestTypeDef",
+    {
+        "Sample": "SampleTypeDef",
+        "Tags": Dict[str, str],
+    },
+    total=False,
+)
+
+
+class CreateProjectRequestTypeDef(
+    _RequiredCreateProjectRequestTypeDef, _OptionalCreateProjectRequestTypeDef
+):
+    pass
+
+
+CreateProjectResponseResponseTypeDef = TypedDict(
+    "CreateProjectResponseResponseTypeDef",
     {
         "Name": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-CreateRecipeJobResponseTypeDef = TypedDict(
-    "CreateRecipeJobResponseTypeDef",
+_RequiredCreateRecipeJobRequestTypeDef = TypedDict(
+    "_RequiredCreateRecipeJobRequestTypeDef",
     {
         "Name": str,
+        "Outputs": List["OutputTypeDef"],
+        "RoleArn": str,
+    },
+)
+_OptionalCreateRecipeJobRequestTypeDef = TypedDict(
+    "_OptionalCreateRecipeJobRequestTypeDef",
+    {
+        "DatasetName": str,
+        "EncryptionKeyArn": str,
+        "EncryptionMode": EncryptionModeType,
+        "LogSubscription": LogSubscriptionType,
+        "MaxCapacity": int,
+        "MaxRetries": int,
+        "ProjectName": str,
+        "RecipeReference": "RecipeReferenceTypeDef",
+        "Tags": Dict[str, str],
+        "Timeout": int,
+    },
+    total=False,
+)
+
+
+class CreateRecipeJobRequestTypeDef(
+    _RequiredCreateRecipeJobRequestTypeDef, _OptionalCreateRecipeJobRequestTypeDef
+):
+    pass
+
+
+CreateRecipeJobResponseResponseTypeDef = TypedDict(
+    "CreateRecipeJobResponseResponseTypeDef",
+    {
+        "Name": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-CreateRecipeResponseTypeDef = TypedDict(
-    "CreateRecipeResponseTypeDef",
+_RequiredCreateRecipeRequestTypeDef = TypedDict(
+    "_RequiredCreateRecipeRequestTypeDef",
     {
         "Name": str,
+        "Steps": List["RecipeStepTypeDef"],
+    },
+)
+_OptionalCreateRecipeRequestTypeDef = TypedDict(
+    "_OptionalCreateRecipeRequestTypeDef",
+    {
+        "Description": str,
+        "Tags": Dict[str, str],
+    },
+    total=False,
+)
+
+
+class CreateRecipeRequestTypeDef(
+    _RequiredCreateRecipeRequestTypeDef, _OptionalCreateRecipeRequestTypeDef
+):
+    pass
+
+
+CreateRecipeResponseResponseTypeDef = TypedDict(
+    "CreateRecipeResponseResponseTypeDef",
+    {
+        "Name": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-CreateScheduleResponseTypeDef = TypedDict(
-    "CreateScheduleResponseTypeDef",
+_RequiredCreateScheduleRequestTypeDef = TypedDict(
+    "_RequiredCreateScheduleRequestTypeDef",
+    {
+        "CronExpression": str,
+        "Name": str,
+    },
+)
+_OptionalCreateScheduleRequestTypeDef = TypedDict(
+    "_OptionalCreateScheduleRequestTypeDef",
+    {
+        "JobNames": List[str],
+        "Tags": Dict[str, str],
+    },
+    total=False,
+)
+
+
+class CreateScheduleRequestTypeDef(
+    _RequiredCreateScheduleRequestTypeDef, _OptionalCreateScheduleRequestTypeDef
+):
+    pass
+
+
+CreateScheduleResponseResponseTypeDef = TypedDict(
+    "CreateScheduleResponseResponseTypeDef",
     {
         "Name": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
@@ -333,87 +532,125 @@ class DatetimeOptionsTypeDef(_RequiredDatetimeOptionsTypeDef, _OptionalDatetimeO
     pass
 
 
-DeleteDatasetResponseTypeDef = TypedDict(
-    "DeleteDatasetResponseTypeDef",
+DeleteDatasetRequestTypeDef = TypedDict(
+    "DeleteDatasetRequestTypeDef",
     {
         "Name": str,
     },
 )
 
-DeleteJobResponseTypeDef = TypedDict(
-    "DeleteJobResponseTypeDef",
+DeleteDatasetResponseResponseTypeDef = TypedDict(
+    "DeleteDatasetResponseResponseTypeDef",
+    {
+        "Name": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DeleteJobRequestTypeDef = TypedDict(
+    "DeleteJobRequestTypeDef",
     {
         "Name": str,
     },
 )
 
-DeleteProjectResponseTypeDef = TypedDict(
-    "DeleteProjectResponseTypeDef",
+DeleteJobResponseResponseTypeDef = TypedDict(
+    "DeleteJobResponseResponseTypeDef",
+    {
+        "Name": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DeleteProjectRequestTypeDef = TypedDict(
+    "DeleteProjectRequestTypeDef",
     {
         "Name": str,
     },
 )
 
-DeleteRecipeVersionResponseTypeDef = TypedDict(
-    "DeleteRecipeVersionResponseTypeDef",
+DeleteProjectResponseResponseTypeDef = TypedDict(
+    "DeleteProjectResponseResponseTypeDef",
+    {
+        "Name": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DeleteRecipeVersionRequestTypeDef = TypedDict(
+    "DeleteRecipeVersionRequestTypeDef",
     {
         "Name": str,
         "RecipeVersion": str,
     },
 )
 
-DeleteScheduleResponseTypeDef = TypedDict(
-    "DeleteScheduleResponseTypeDef",
+DeleteRecipeVersionResponseResponseTypeDef = TypedDict(
+    "DeleteRecipeVersionResponseResponseTypeDef",
+    {
+        "Name": str,
+        "RecipeVersion": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DeleteScheduleRequestTypeDef = TypedDict(
+    "DeleteScheduleRequestTypeDef",
     {
         "Name": str,
     },
 )
 
-_RequiredDescribeDatasetResponseTypeDef = TypedDict(
-    "_RequiredDescribeDatasetResponseTypeDef",
+DeleteScheduleResponseResponseTypeDef = TypedDict(
+    "DeleteScheduleResponseResponseTypeDef",
     {
         "Name": str,
-        "Input": "InputTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
-_OptionalDescribeDatasetResponseTypeDef = TypedDict(
-    "_OptionalDescribeDatasetResponseTypeDef",
+
+DescribeDatasetRequestTypeDef = TypedDict(
+    "DescribeDatasetRequestTypeDef",
+    {
+        "Name": str,
+    },
+)
+
+DescribeDatasetResponseResponseTypeDef = TypedDict(
+    "DescribeDatasetResponseResponseTypeDef",
     {
         "CreatedBy": str,
         "CreateDate": datetime,
+        "Name": str,
         "Format": InputFormatType,
         "FormatOptions": "FormatOptionsTypeDef",
+        "Input": "InputTypeDef",
         "LastModifiedDate": datetime,
         "LastModifiedBy": str,
         "Source": SourceType,
         "PathOptions": "PathOptionsTypeDef",
         "Tags": Dict[str, str],
         "ResourceArn": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-
-class DescribeDatasetResponseTypeDef(
-    _RequiredDescribeDatasetResponseTypeDef, _OptionalDescribeDatasetResponseTypeDef
-):
-    pass
-
-
-_RequiredDescribeJobResponseTypeDef = TypedDict(
-    "_RequiredDescribeJobResponseTypeDef",
+DescribeJobRequestTypeDef = TypedDict(
+    "DescribeJobRequestTypeDef",
     {
         "Name": str,
     },
 )
-_OptionalDescribeJobResponseTypeDef = TypedDict(
-    "_OptionalDescribeJobResponseTypeDef",
+
+DescribeJobResponseResponseTypeDef = TypedDict(
+    "DescribeJobResponseResponseTypeDef",
     {
         "CreateDate": datetime,
         "CreatedBy": str,
         "DatasetName": str,
         "EncryptionKeyArn": str,
         "EncryptionMode": EncryptionModeType,
+        "Name": str,
         "Type": JobTypeType,
         "LastModifiedBy": str,
         "LastModifiedDate": datetime,
@@ -428,31 +665,27 @@ _OptionalDescribeJobResponseTypeDef = TypedDict(
         "Tags": Dict[str, str],
         "Timeout": int,
         "JobSample": "JobSampleTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-
-class DescribeJobResponseTypeDef(
-    _RequiredDescribeJobResponseTypeDef, _OptionalDescribeJobResponseTypeDef
-):
-    pass
-
-
-_RequiredDescribeJobRunResponseTypeDef = TypedDict(
-    "_RequiredDescribeJobRunResponseTypeDef",
+DescribeJobRunRequestTypeDef = TypedDict(
+    "DescribeJobRunRequestTypeDef",
     {
-        "JobName": str,
+        "Name": str,
+        "RunId": str,
     },
 )
-_OptionalDescribeJobRunResponseTypeDef = TypedDict(
-    "_OptionalDescribeJobRunResponseTypeDef",
+
+DescribeJobRunResponseResponseTypeDef = TypedDict(
+    "DescribeJobRunResponseResponseTypeDef",
     {
         "Attempt": int,
         "CompletedOn": datetime,
         "DatasetName": str,
         "ErrorMessage": str,
         "ExecutionTime": int,
+        "JobName": str,
         "RunId": str,
         "State": JobRunStateType,
         "LogSubscription": LogSubscriptionType,
@@ -462,31 +695,26 @@ _OptionalDescribeJobRunResponseTypeDef = TypedDict(
         "StartedBy": str,
         "StartedOn": datetime,
         "JobSample": "JobSampleTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-
-class DescribeJobRunResponseTypeDef(
-    _RequiredDescribeJobRunResponseTypeDef, _OptionalDescribeJobRunResponseTypeDef
-):
-    pass
-
-
-_RequiredDescribeProjectResponseTypeDef = TypedDict(
-    "_RequiredDescribeProjectResponseTypeDef",
+DescribeProjectRequestTypeDef = TypedDict(
+    "DescribeProjectRequestTypeDef",
     {
         "Name": str,
     },
 )
-_OptionalDescribeProjectResponseTypeDef = TypedDict(
-    "_OptionalDescribeProjectResponseTypeDef",
+
+DescribeProjectResponseResponseTypeDef = TypedDict(
+    "DescribeProjectResponseResponseTypeDef",
     {
         "CreateDate": datetime,
         "CreatedBy": str,
         "DatasetName": str,
         "LastModifiedDate": datetime,
         "LastModifiedBy": str,
+        "Name": str,
         "RecipeName": str,
         "ResourceArn": str,
         "Sample": "SampleTypeDef",
@@ -495,25 +723,33 @@ _OptionalDescribeProjectResponseTypeDef = TypedDict(
         "SessionStatus": SessionStatusType,
         "OpenedBy": str,
         "OpenDate": datetime,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredDescribeRecipeRequestTypeDef = TypedDict(
+    "_RequiredDescribeRecipeRequestTypeDef",
+    {
+        "Name": str,
+    },
+)
+_OptionalDescribeRecipeRequestTypeDef = TypedDict(
+    "_OptionalDescribeRecipeRequestTypeDef",
+    {
+        "RecipeVersion": str,
     },
     total=False,
 )
 
 
-class DescribeProjectResponseTypeDef(
-    _RequiredDescribeProjectResponseTypeDef, _OptionalDescribeProjectResponseTypeDef
+class DescribeRecipeRequestTypeDef(
+    _RequiredDescribeRecipeRequestTypeDef, _OptionalDescribeRecipeRequestTypeDef
 ):
     pass
 
 
-_RequiredDescribeRecipeResponseTypeDef = TypedDict(
-    "_RequiredDescribeRecipeResponseTypeDef",
-    {
-        "Name": str,
-    },
-)
-_OptionalDescribeRecipeResponseTypeDef = TypedDict(
-    "_OptionalDescribeRecipeResponseTypeDef",
+DescribeRecipeResponseResponseTypeDef = TypedDict(
+    "DescribeRecipeResponseResponseTypeDef",
     {
         "CreatedBy": str,
         "CreateDate": datetime,
@@ -523,29 +759,24 @@ _OptionalDescribeRecipeResponseTypeDef = TypedDict(
         "PublishedBy": str,
         "PublishedDate": datetime,
         "Description": str,
+        "Name": str,
         "Steps": List["RecipeStepTypeDef"],
         "Tags": Dict[str, str],
         "ResourceArn": str,
         "RecipeVersion": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-
-class DescribeRecipeResponseTypeDef(
-    _RequiredDescribeRecipeResponseTypeDef, _OptionalDescribeRecipeResponseTypeDef
-):
-    pass
-
-
-_RequiredDescribeScheduleResponseTypeDef = TypedDict(
-    "_RequiredDescribeScheduleResponseTypeDef",
+DescribeScheduleRequestTypeDef = TypedDict(
+    "DescribeScheduleRequestTypeDef",
     {
         "Name": str,
     },
 )
-_OptionalDescribeScheduleResponseTypeDef = TypedDict(
-    "_OptionalDescribeScheduleResponseTypeDef",
+
+DescribeScheduleResponseResponseTypeDef = TypedDict(
+    "DescribeScheduleResponseResponseTypeDef",
     {
         "CreateDate": datetime,
         "CreatedBy": str,
@@ -555,17 +786,11 @@ _OptionalDescribeScheduleResponseTypeDef = TypedDict(
         "ResourceArn": str,
         "CronExpression": str,
         "Tags": Dict[str, str],
+        "Name": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-
-class DescribeScheduleResponseTypeDef(
-    _RequiredDescribeScheduleResponseTypeDef, _OptionalDescribeScheduleResponseTypeDef
-):
-    pass
-
-
 ExcelOptionsTypeDef = TypedDict(
     "ExcelOptionsTypeDef",
     {
@@ -701,157 +926,175 @@ JsonOptionsTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredListDatasetsResponseTypeDef = TypedDict(
-    "_RequiredListDatasetsResponseTypeDef",
+ListDatasetsRequestTypeDef = TypedDict(
+    "ListDatasetsRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+ListDatasetsResponseResponseTypeDef = TypedDict(
+    "ListDatasetsResponseResponseTypeDef",
     {
         "Datasets": List["DatasetTypeDef"],
+        "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
-_OptionalListDatasetsResponseTypeDef = TypedDict(
-    "_OptionalListDatasetsResponseTypeDef",
+
+_RequiredListJobRunsRequestTypeDef = TypedDict(
+    "_RequiredListJobRunsRequestTypeDef",
     {
+        "Name": str,
+    },
+)
+_OptionalListJobRunsRequestTypeDef = TypedDict(
+    "_OptionalListJobRunsRequestTypeDef",
+    {
+        "MaxResults": int,
         "NextToken": str,
     },
     total=False,
 )
 
 
-class ListDatasetsResponseTypeDef(
-    _RequiredListDatasetsResponseTypeDef, _OptionalListDatasetsResponseTypeDef
+class ListJobRunsRequestTypeDef(
+    _RequiredListJobRunsRequestTypeDef, _OptionalListJobRunsRequestTypeDef
 ):
     pass
 
 
-_RequiredListJobRunsResponseTypeDef = TypedDict(
-    "_RequiredListJobRunsResponseTypeDef",
+ListJobRunsResponseResponseTypeDef = TypedDict(
+    "ListJobRunsResponseResponseTypeDef",
     {
         "JobRuns": List["JobRunTypeDef"],
+        "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
-_OptionalListJobRunsResponseTypeDef = TypedDict(
-    "_OptionalListJobRunsResponseTypeDef",
+
+ListJobsRequestTypeDef = TypedDict(
+    "ListJobsRequestTypeDef",
     {
+        "DatasetName": str,
+        "MaxResults": int,
         "NextToken": str,
+        "ProjectName": str,
     },
     total=False,
 )
 
-
-class ListJobRunsResponseTypeDef(
-    _RequiredListJobRunsResponseTypeDef, _OptionalListJobRunsResponseTypeDef
-):
-    pass
-
-
-_RequiredListJobsResponseTypeDef = TypedDict(
-    "_RequiredListJobsResponseTypeDef",
+ListJobsResponseResponseTypeDef = TypedDict(
+    "ListJobsResponseResponseTypeDef",
     {
         "Jobs": List["JobTypeDef"],
+        "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
-_OptionalListJobsResponseTypeDef = TypedDict(
-    "_OptionalListJobsResponseTypeDef",
+
+ListProjectsRequestTypeDef = TypedDict(
+    "ListProjectsRequestTypeDef",
     {
         "NextToken": str,
+        "MaxResults": int,
     },
     total=False,
 )
 
-
-class ListJobsResponseTypeDef(_RequiredListJobsResponseTypeDef, _OptionalListJobsResponseTypeDef):
-    pass
-
-
-_RequiredListProjectsResponseTypeDef = TypedDict(
-    "_RequiredListProjectsResponseTypeDef",
+ListProjectsResponseResponseTypeDef = TypedDict(
+    "ListProjectsResponseResponseTypeDef",
     {
         "Projects": List["ProjectTypeDef"],
+        "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
-_OptionalListProjectsResponseTypeDef = TypedDict(
-    "_OptionalListProjectsResponseTypeDef",
+
+_RequiredListRecipeVersionsRequestTypeDef = TypedDict(
+    "_RequiredListRecipeVersionsRequestTypeDef",
     {
+        "Name": str,
+    },
+)
+_OptionalListRecipeVersionsRequestTypeDef = TypedDict(
+    "_OptionalListRecipeVersionsRequestTypeDef",
+    {
+        "MaxResults": int,
         "NextToken": str,
     },
     total=False,
 )
 
 
-class ListProjectsResponseTypeDef(
-    _RequiredListProjectsResponseTypeDef, _OptionalListProjectsResponseTypeDef
+class ListRecipeVersionsRequestTypeDef(
+    _RequiredListRecipeVersionsRequestTypeDef, _OptionalListRecipeVersionsRequestTypeDef
 ):
     pass
 
 
-_RequiredListRecipeVersionsResponseTypeDef = TypedDict(
-    "_RequiredListRecipeVersionsResponseTypeDef",
+ListRecipeVersionsResponseResponseTypeDef = TypedDict(
+    "ListRecipeVersionsResponseResponseTypeDef",
+    {
+        "NextToken": str,
+        "Recipes": List["RecipeTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListRecipesRequestTypeDef = TypedDict(
+    "ListRecipesRequestTypeDef",
+    {
+        "MaxResults": int,
+        "NextToken": str,
+        "RecipeVersion": str,
+    },
+    total=False,
+)
+
+ListRecipesResponseResponseTypeDef = TypedDict(
+    "ListRecipesResponseResponseTypeDef",
     {
         "Recipes": List["RecipeTypeDef"],
+        "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
-_OptionalListRecipeVersionsResponseTypeDef = TypedDict(
-    "_OptionalListRecipeVersionsResponseTypeDef",
+
+ListSchedulesRequestTypeDef = TypedDict(
+    "ListSchedulesRequestTypeDef",
     {
+        "JobName": str,
+        "MaxResults": int,
         "NextToken": str,
     },
     total=False,
 )
 
-
-class ListRecipeVersionsResponseTypeDef(
-    _RequiredListRecipeVersionsResponseTypeDef, _OptionalListRecipeVersionsResponseTypeDef
-):
-    pass
-
-
-_RequiredListRecipesResponseTypeDef = TypedDict(
-    "_RequiredListRecipesResponseTypeDef",
-    {
-        "Recipes": List["RecipeTypeDef"],
-    },
-)
-_OptionalListRecipesResponseTypeDef = TypedDict(
-    "_OptionalListRecipesResponseTypeDef",
-    {
-        "NextToken": str,
-    },
-    total=False,
-)
-
-
-class ListRecipesResponseTypeDef(
-    _RequiredListRecipesResponseTypeDef, _OptionalListRecipesResponseTypeDef
-):
-    pass
-
-
-_RequiredListSchedulesResponseTypeDef = TypedDict(
-    "_RequiredListSchedulesResponseTypeDef",
+ListSchedulesResponseResponseTypeDef = TypedDict(
+    "ListSchedulesResponseResponseTypeDef",
     {
         "Schedules": List["ScheduleTypeDef"],
-    },
-)
-_OptionalListSchedulesResponseTypeDef = TypedDict(
-    "_OptionalListSchedulesResponseTypeDef",
-    {
         "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
+ListTagsForResourceRequestTypeDef = TypedDict(
+    "ListTagsForResourceRequestTypeDef",
+    {
+        "ResourceArn": str,
+    },
+)
 
-class ListSchedulesResponseTypeDef(
-    _RequiredListSchedulesResponseTypeDef, _OptionalListSchedulesResponseTypeDef
-):
-    pass
-
-
-ListTagsForResourceResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseTypeDef",
+ListTagsForResourceResponseResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseResponseTypeDef",
     {
         "Tags": Dict[str, str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 OutputFormatOptionsTypeDef = TypedDict(
@@ -862,19 +1105,29 @@ OutputFormatOptionsTypeDef = TypedDict(
     total=False,
 )
 
-OutputTypeDef = TypedDict(
-    "OutputTypeDef",
+_RequiredOutputTypeDef = TypedDict(
+    "_RequiredOutputTypeDef",
+    {
+        "Location": "S3LocationTypeDef",
+    },
+)
+_OptionalOutputTypeDef = TypedDict(
+    "_OptionalOutputTypeDef",
     {
         "CompressionFormat": CompressionFormatType,
         "Format": OutputFormatType,
         "PartitionColumns": List[str],
-        "Location": "S3LocationTypeDef",
         "Overwrite": bool,
         "FormatOptions": "OutputFormatOptionsTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
+    total=False,
 )
 
+
+class OutputTypeDef(_RequiredOutputTypeDef, _OptionalOutputTypeDef):
+    pass
+
+
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
     {
@@ -926,12 +1179,34 @@ class ProjectTypeDef(_RequiredProjectTypeDef, _OptionalProjectTypeDef):
     pass
 
 
-PublishRecipeResponseTypeDef = TypedDict(
-    "PublishRecipeResponseTypeDef",
+_RequiredPublishRecipeRequestTypeDef = TypedDict(
+    "_RequiredPublishRecipeRequestTypeDef",
     {
         "Name": str,
     },
 )
+_OptionalPublishRecipeRequestTypeDef = TypedDict(
+    "_OptionalPublishRecipeRequestTypeDef",
+    {
+        "Description": str,
+    },
+    total=False,
+)
+
+
+class PublishRecipeRequestTypeDef(
+    _RequiredPublishRecipeRequestTypeDef, _OptionalPublishRecipeRequestTypeDef
+):
+    pass
+
+
+PublishRecipeResponseResponseTypeDef = TypedDict(
+    "PublishRecipeResponseResponseTypeDef",
+    {
+        "Name": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
 
 _RequiredRecipeActionTypeDef = TypedDict(
     "_RequiredRecipeActionTypeDef",
@@ -1106,117 +1381,311 @@ class ScheduleTypeDef(_RequiredScheduleTypeDef, _OptionalScheduleTypeDef):
     pass
 
 
-_RequiredSendProjectSessionActionResponseTypeDef = TypedDict(
-    "_RequiredSendProjectSessionActionResponseTypeDef",
+_RequiredSendProjectSessionActionRequestTypeDef = TypedDict(
+    "_RequiredSendProjectSessionActionRequestTypeDef",
     {
         "Name": str,
     },
 )
-_OptionalSendProjectSessionActionResponseTypeDef = TypedDict(
-    "_OptionalSendProjectSessionActionResponseTypeDef",
+_OptionalSendProjectSessionActionRequestTypeDef = TypedDict(
+    "_OptionalSendProjectSessionActionRequestTypeDef",
+    {
+        "Preview": bool,
+        "RecipeStep": "RecipeStepTypeDef",
+        "StepIndex": int,
+        "ClientSessionId": str,
+        "ViewFrame": "ViewFrameTypeDef",
+    },
+    total=False,
+)
+
+
+class SendProjectSessionActionRequestTypeDef(
+    _RequiredSendProjectSessionActionRequestTypeDef, _OptionalSendProjectSessionActionRequestTypeDef
+):
+    pass
+
+
+SendProjectSessionActionResponseResponseTypeDef = TypedDict(
+    "SendProjectSessionActionResponseResponseTypeDef",
     {
         "Result": str,
+        "Name": str,
         "ActionId": int,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+StartJobRunRequestTypeDef = TypedDict(
+    "StartJobRunRequestTypeDef",
+    {
+        "Name": str,
+    },
+)
+
+StartJobRunResponseResponseTypeDef = TypedDict(
+    "StartJobRunResponseResponseTypeDef",
+    {
+        "RunId": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredStartProjectSessionRequestTypeDef = TypedDict(
+    "_RequiredStartProjectSessionRequestTypeDef",
+    {
+        "Name": str,
+    },
+)
+_OptionalStartProjectSessionRequestTypeDef = TypedDict(
+    "_OptionalStartProjectSessionRequestTypeDef",
+    {
+        "AssumeControl": bool,
     },
     total=False,
 )
 
 
-class SendProjectSessionActionResponseTypeDef(
-    _RequiredSendProjectSessionActionResponseTypeDef,
-    _OptionalSendProjectSessionActionResponseTypeDef,
+class StartProjectSessionRequestTypeDef(
+    _RequiredStartProjectSessionRequestTypeDef, _OptionalStartProjectSessionRequestTypeDef
 ):
     pass
 
 
-StartJobRunResponseTypeDef = TypedDict(
-    "StartJobRunResponseTypeDef",
-    {
-        "RunId": str,
-    },
-)
-
-_RequiredStartProjectSessionResponseTypeDef = TypedDict(
-    "_RequiredStartProjectSessionResponseTypeDef",
+StartProjectSessionResponseResponseTypeDef = TypedDict(
+    "StartProjectSessionResponseResponseTypeDef",
     {
         "Name": str,
-    },
-)
-_OptionalStartProjectSessionResponseTypeDef = TypedDict(
-    "_OptionalStartProjectSessionResponseTypeDef",
-    {
         "ClientSessionId": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+StopJobRunRequestTypeDef = TypedDict(
+    "StopJobRunRequestTypeDef",
+    {
+        "Name": str,
+        "RunId": str,
+    },
+)
+
+StopJobRunResponseResponseTypeDef = TypedDict(
+    "StopJobRunResponseResponseTypeDef",
+    {
+        "RunId": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+TagResourceRequestTypeDef = TypedDict(
+    "TagResourceRequestTypeDef",
+    {
+        "ResourceArn": str,
+        "Tags": Dict[str, str],
+    },
+)
+
+UntagResourceRequestTypeDef = TypedDict(
+    "UntagResourceRequestTypeDef",
+    {
+        "ResourceArn": str,
+        "TagKeys": List[str],
+    },
+)
+
+_RequiredUpdateDatasetRequestTypeDef = TypedDict(
+    "_RequiredUpdateDatasetRequestTypeDef",
+    {
+        "Name": str,
+        "Input": "InputTypeDef",
+    },
+)
+_OptionalUpdateDatasetRequestTypeDef = TypedDict(
+    "_OptionalUpdateDatasetRequestTypeDef",
+    {
+        "Format": InputFormatType,
+        "FormatOptions": "FormatOptionsTypeDef",
+        "PathOptions": "PathOptionsTypeDef",
     },
     total=False,
 )
 
 
-class StartProjectSessionResponseTypeDef(
-    _RequiredStartProjectSessionResponseTypeDef, _OptionalStartProjectSessionResponseTypeDef
+class UpdateDatasetRequestTypeDef(
+    _RequiredUpdateDatasetRequestTypeDef, _OptionalUpdateDatasetRequestTypeDef
 ):
     pass
 
 
-StopJobRunResponseTypeDef = TypedDict(
-    "StopJobRunResponseTypeDef",
+UpdateDatasetResponseResponseTypeDef = TypedDict(
+    "UpdateDatasetResponseResponseTypeDef",
     {
-        "RunId": str,
+        "Name": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-UpdateDatasetResponseTypeDef = TypedDict(
-    "UpdateDatasetResponseTypeDef",
+_RequiredUpdateProfileJobRequestTypeDef = TypedDict(
+    "_RequiredUpdateProfileJobRequestTypeDef",
     {
         "Name": str,
+        "OutputLocation": "S3LocationTypeDef",
+        "RoleArn": str,
+    },
+)
+_OptionalUpdateProfileJobRequestTypeDef = TypedDict(
+    "_OptionalUpdateProfileJobRequestTypeDef",
+    {
+        "EncryptionKeyArn": str,
+        "EncryptionMode": EncryptionModeType,
+        "LogSubscription": LogSubscriptionType,
+        "MaxCapacity": int,
+        "MaxRetries": int,
+        "Timeout": int,
+        "JobSample": "JobSampleTypeDef",
+    },
+    total=False,
+)
+
+
+class UpdateProfileJobRequestTypeDef(
+    _RequiredUpdateProfileJobRequestTypeDef, _OptionalUpdateProfileJobRequestTypeDef
+):
+    pass
+
+
+UpdateProfileJobResponseResponseTypeDef = TypedDict(
+    "UpdateProfileJobResponseResponseTypeDef",
+    {
+        "Name": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-UpdateProfileJobResponseTypeDef = TypedDict(
-    "UpdateProfileJobResponseTypeDef",
+_RequiredUpdateProjectRequestTypeDef = TypedDict(
+    "_RequiredUpdateProjectRequestTypeDef",
     {
+        "RoleArn": str,
         "Name": str,
     },
 )
+_OptionalUpdateProjectRequestTypeDef = TypedDict(
+    "_OptionalUpdateProjectRequestTypeDef",
+    {
+        "Sample": "SampleTypeDef",
+    },
+    total=False,
+)
 
-_RequiredUpdateProjectResponseTypeDef = TypedDict(
-    "_RequiredUpdateProjectResponseTypeDef",
-    {
-        "Name": str,
-    },
-)
-_OptionalUpdateProjectResponseTypeDef = TypedDict(
-    "_OptionalUpdateProjectResponseTypeDef",
+
+class UpdateProjectRequestTypeDef(
+    _RequiredUpdateProjectRequestTypeDef, _OptionalUpdateProjectRequestTypeDef
+):
+    pass
+
+
+UpdateProjectResponseResponseTypeDef = TypedDict(
+    "UpdateProjectResponseResponseTypeDef",
     {
         "LastModifiedDate": datetime,
+        "Name": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredUpdateRecipeJobRequestTypeDef = TypedDict(
+    "_RequiredUpdateRecipeJobRequestTypeDef",
+    {
+        "Name": str,
+        "Outputs": List["OutputTypeDef"],
+        "RoleArn": str,
+    },
+)
+_OptionalUpdateRecipeJobRequestTypeDef = TypedDict(
+    "_OptionalUpdateRecipeJobRequestTypeDef",
+    {
+        "EncryptionKeyArn": str,
+        "EncryptionMode": EncryptionModeType,
+        "LogSubscription": LogSubscriptionType,
+        "MaxCapacity": int,
+        "MaxRetries": int,
+        "Timeout": int,
     },
     total=False,
 )
 
 
-class UpdateProjectResponseTypeDef(
-    _RequiredUpdateProjectResponseTypeDef, _OptionalUpdateProjectResponseTypeDef
+class UpdateRecipeJobRequestTypeDef(
+    _RequiredUpdateRecipeJobRequestTypeDef, _OptionalUpdateRecipeJobRequestTypeDef
 ):
     pass
 
 
-UpdateRecipeJobResponseTypeDef = TypedDict(
-    "UpdateRecipeJobResponseTypeDef",
+UpdateRecipeJobResponseResponseTypeDef = TypedDict(
+    "UpdateRecipeJobResponseResponseTypeDef",
+    {
+        "Name": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredUpdateRecipeRequestTypeDef = TypedDict(
+    "_RequiredUpdateRecipeRequestTypeDef",
     {
         "Name": str,
     },
 )
+_OptionalUpdateRecipeRequestTypeDef = TypedDict(
+    "_OptionalUpdateRecipeRequestTypeDef",
+    {
+        "Description": str,
+        "Steps": List["RecipeStepTypeDef"],
+    },
+    total=False,
+)
 
-UpdateRecipeResponseTypeDef = TypedDict(
-    "UpdateRecipeResponseTypeDef",
+
+class UpdateRecipeRequestTypeDef(
+    _RequiredUpdateRecipeRequestTypeDef, _OptionalUpdateRecipeRequestTypeDef
+):
+    pass
+
+
+UpdateRecipeResponseResponseTypeDef = TypedDict(
+    "UpdateRecipeResponseResponseTypeDef",
     {
         "Name": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-UpdateScheduleResponseTypeDef = TypedDict(
-    "UpdateScheduleResponseTypeDef",
+_RequiredUpdateScheduleRequestTypeDef = TypedDict(
+    "_RequiredUpdateScheduleRequestTypeDef",
+    {
+        "CronExpression": str,
+        "Name": str,
+    },
+)
+_OptionalUpdateScheduleRequestTypeDef = TypedDict(
+    "_OptionalUpdateScheduleRequestTypeDef",
+    {
+        "JobNames": List[str],
+    },
+    total=False,
+)
+
+
+class UpdateScheduleRequestTypeDef(
+    _RequiredUpdateScheduleRequestTypeDef, _OptionalUpdateScheduleRequestTypeDef
+):
+    pass
+
+
+UpdateScheduleResponseResponseTypeDef = TypedDict(
+    "UpdateScheduleResponseResponseTypeDef",
     {
         "Name": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
